Learn R Programming

snotelr (version 1.2)

snotel_phenology: Calculates snow phenology from the snow water equivalent data

Description

First snow melt, first continuous snow melt, first snow accumulation and continous snow accumulation are reported.

Usage

snotel_phenology(df, threshold = 0)

Arguments

df

a snotel data file or data frame

threshold

threshold for mapping continuous snow cover

Details

Be sure to execute this code on individual sites when loading a combined tidy data frame containing data for multiple sites.

Examples

Run this code

if (FALSE) {
# download one of the longer time series
df <- snotel_download(site_id = 670, internal = TRUE)

# calculate the snow phenology
phenology <- snotel_phenology(df)

# show a couple of lines
head(phenology)

}

Run the code above in your browser using DataLab